use NRT::Test;
use NRT::Helper;
use NRT::User;

package Batch;

sub new {
    my ($classe, %config) = @_;
    my $this = {};
    $classe = ref($classe) || $classe;
    bless ( $this, $classe );
    $this->{config} = {%config} ;
    $this->{tester} = Test->new( %config );
    $this->{users} = [];
    $this->{users_index} = 0;
    return $this;
}

sub test_rq_empty {
  my $this = shift;
  my $rq = $this->{tester}->get_code();  
  return $this->{tester}->assertEqual( $rq, "404 Not Found" );
}

sub test_user {
  my $this = shift;
  my $user1_index = $this->add_user(
    $this->{config}{Authentification}{Email},
    $this->{config}{Authentification}{Username},
    $this->{config}{Authentification}{Password} );
  $this->{tester}->test_user_authentification(
    $this->{users}[$user1_index]);
  $this->{tester}->test_user_already_created( 
    $this->{users}[$user1_index]);
  my $user2_index = $this->add_user(
    $this->{config}{User}{Email},
    $this->{config}{User}{Username},
      $this->{config}{User}{Password} );
  $this->{tester}->test_user_not_exists(
    $this->{users}[$user2_index]);
  $this->{tester}->test_user_create(
    $this->{users}[$user2_index]);
  $this->{tester}->test_user_exists(
    $this->{users}[$user2_index]);
  $this->{tester}->test_user_remove(
    $this->{users}[$user2_index]);
  $this->{tester}->test_user_removed(
    $this->{users}[$user2_index]);
  $this->{tester}->test_user_already_removed(
    $this->{users}[$user2_index]);
}

sub add_user {
  my ($this, $email, $username, $password) = @_ ;
  push(
    @{$this->{users}},
      User->new( $email, $username, $password, $this->{tester})) ;
  return $this->{users_index}++;
}

sub run {
  my $this = shift;
  $this->test_rq_empty();
  $this->test_user();
  $this->brief();
}

sub brief {
  my $this = shift;;
  print "\nResults :\n";
  Helper::printColor( "bright_green", "Tests succeed : ".$this->{tester}->{countSuccess}."\n" );
  Helper::printColor( "bright_red", "Tests failed  : ".$this->{tester}->{countFailure}."\n" );
}

return 1;
